---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:decreto.legislativo:2002-01-23;10
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=20020215&codiceRedaz=002G0032&dataVigenza=20251104
dataGU: 20020215
codiceRedaz: 002G0032
dataVigenza: 20251104
---

# Attuazione della direttiva 1999/93/CE relativa ad un quadro comunitario per le firme elettroniche.

## Art. 1.

((PROVVEDIMENTO ABROGATO DAL D.LGS. 7 MARZO 2005, N. 82))

## Art. 2.

((PROVVEDIMENTO ABROGATO DAL D.LGS. 7 MARZO 2005, N. 82))

## Art. 3.

((PROVVEDIMENTO ABROGATO DAL D.LGS. 7 MARZO 2005, N. 82))

## Art. 4.

((PROVVEDIMENTO ABROGATO DAL D.LGS. 7 MARZO 2005, N. 82))

## Art. 5.

((PROVVEDIMENTO ABROGATO DAL D.LGS. 7 MARZO 2005, N. 82))

## Art. 6.

((PROVVEDIMENTO ABROGATO DAL D.LGS. 7 MARZO 2005, N. 82))

## Art. 7.

((PROVVEDIMENTO ABROGATO DAL D.LGS. 7 MARZO 2005, N. 82))

## Art. 8.

((PROVVEDIMENTO ABROGATO DAL D.LGS. 7 MARZO 2005, N. 82))

## Art. 9.

((PROVVEDIMENTO ABROGATO DAL D.LGS. 7 MARZO 2005, N. 82))

## Art. 10.

((PROVVEDIMENTO ABROGATO DAL D.LGS. 7 MARZO 2005, N. 82))

## Art. 11.

((PROVVEDIMENTO ABROGATO DAL D.LGS. 7 MARZO 2005, N. 82))

## Art. 12.

((PROVVEDIMENTO ABROGATO DAL D.LGS. 7 MARZO 2005, N. 82))

## Art. 13.

((PROVVEDIMENTO ABROGATO DAL D.LGS. 7 MARZO 2005, N. 82))

